@@ -96,6 +96,33 @@ class Client:
                 headers=response.headers)
         return res
 
+    def check_usage(
+            self,
+            headers: dict = {},
+        ):
+        try:
+            res = self.check_api_key()
+            if not res['valid']:
+                raise ClueaiError('invalid api key')
+        except ClueaiError as e:
+            raise ClueaiError(
+                message=e.message,
+                http_status=e.http_status,
+                headers=e.headers)
+
+        tmp_headers = {
+            'Api-Key': 'BEARER {}'.format(self.api_key),
+            'Content-Type': 'application/json',
+            'Request-Source': 'python-sdk',
+        }
+        if self.modelfun_version != '':
+            tmp_headers['clueai-Version'] = self.modelfun_version
+
+        res = requests.get(f"{self.clueai_api_url}/serving/api/user_info?api_key={self.api_key}", 
+            headers=tmp_headers)
+
+        return res.json()
+
     def upload_finetune_corpus(
         self,
         file_path: str,
@@ -105,6 +132,16 @@ class Client:
         model_name: str = None,
         sync: bool = True
         ):
+        try:
+            res = self.check_api_key()
+            if not res['valid']:
+                raise ClueaiError('invalid api key')
+        except ClueaiError as e:
+            raise ClueaiError(
+                message=e.message,
+                http_status=e.http_status,
+                headers=e.headers)
+
         tmp_headers = {
             'Api-Key': 'BEARER {}'.format(self.api_key),
             'Content-Type': 'application/json',
@@ -131,6 +168,16 @@ class Client:
         json_body = {
             'engine_key': engine_key,
         }
+        try:
+            res = self.check_api_key()
+            if not res['valid']:
+                raise ClueaiError('invalid api key')
+        except ClueaiError as e:
+            raise ClueaiError(
+                message=e.message,
+                http_status=e.http_status,
+                headers=e.headers)
+
         tmp_headers = {
             'Api-Key': 'BEARER {}'.format(self.api_key),
             'Content-Type': 'application/json',
@@ -161,6 +208,16 @@ class Client:
         headers: dict = {},
         generate_config: dict = {}
     ) -> Generations:
+        try:
+            res = self.check_api_key()
+            if not res['valid']:
+                raise ClueaiError('invalid api key')
+        except ClueaiError as e:
+            raise ClueaiError(
+                message=e.message,
+                http_status=e.http_status,
+                headers=e.headers)
+                
         json_body = {
             'engine_key': engine_key,
             'task_type': "generate",
@@ -354,6 +411,8 @@ class Client:
             'labels': labels
         }, ensure_ascii=False)
         response = self.__request(json_body, clueai.CLASSIFY_URL, model_name)
+        if "result" not in response:
+            raise ClueaiError(f'No result in response, please check or try. error{response}')
         classifications = []
         for res in response['result']:
             confidenceObj = []
